# -*- coding: utf-8 -*-

# Copyright (C) 2008-2014 Avencall
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>

import logging
from firebase_admin import messaging, initialize_app
from firebase_admin.exceptions import FirebaseError
from xivo_agid import agid
from xivo_agid.handlers.userfeatures import UserFeatures

logger = logging.getLogger(__name__)


def mobile_push_notification(agi, cursor, args, dry_run=False):
    app = initialize_app()
    token = agi.get_variable(UserFeatures.MOBILE_PUSH_TOKEN)
    if token != UserFeatures.NOT_REGISTERED:
        # TODO more platform message? https://github.com/firebase/firebase-admin-python/blob/02596dc149d05fa69c8288c0f3c73cef60ebff41/snippets/messaging/cloud_messaging.py#L161
        message = messaging.Message(token=token)
        try:
            # TODO what about error during delivering?
            response = messaging.send(message, dry_run=dry_run)
        except ValueError as e:
            logger.error(f"Invalid input arguments: %s", e)
            raise
        except FirebaseError as e:
            logger.error(f"Error while sending message to FCM service: %s", e)
        else:
            logger.debug("Response: %s", response)


agid.register(mobile_push_notification)
